=================
Input File Parser
=================

The inpParser module provides functions that allow you to parse an Abaqus input file.

Create input files
------------------

.. autoclass:: abaqus.InputFileParser.InputFile.InputFile
    :noindex:

Object features
---------------

AbaqusNDarray
~~~~~~~~~~~~~

.. autoclass:: abaqus.InputFileParser.AbaqusNDarray.AbaqusNDarray
    :members:

    .. autoclasstoc::

InputFile
~~~~~~~~~

.. autoclass:: abaqus.InputFileParser.InputFile.InputFile
    :members:

    .. autoclasstoc::

Keyword
~~~~~~~

.. autoclass:: abaqus.InputFileParser.Keyword.Keyword
    :members:

    .. autoclasstoc::

